==> SAGElyzer_1.3.0.tar.gz: SAGElyzer/R/zzz.R <==

.First.lib <- function(libname, pkgname, where) {
    require(AnnBuilder) || stop("Package annotate unavailable")
    require(genefilter) || stop("Package genefilter unavailable")
    require(annotate) || stop("Package annotate unavailable")
    if(.Platform$OS.type == "windows"){
        require(RODBC) || stop("package RODBC unavailable")
    }else if(.Platform$OS.type == "unix"){
        require(Rdbi) || stop("Package Rdbi unavailable")
        require(RdbiPgSQL) || stop("Package RdbiPgSQL unavailable")
    }

    if(interactive()){
        setSLyzerArgs()
        if(require(tcltk, quietly = TRUE)){
            require(tkWidgets) || stop("Package tkWidgets unavailable")
            SAGEWidget()
        }
    }


#    if(interactive()){
#        if(require(tcltk, quietly = TRUE)){
#            require(tkWidgets) || stop("Package tkWidgets unavailable")
#            if(.Platform$OS.type == "windows"){
#                require(Biobase) || stop("Package Biobase unavailable")
#                addVig2Menu("DBConnecter", "SAGE",
#                             itemAction = "getDBArgs()")
#                addVig2Menu("Get GEOSAGE", "SAGE/SAGEIntegrater",
#                                           itemAction = "SAGEFromGEO()")
#                addVig2Menu("Integrate SAGE", "SAGE/SAGEIntegrater",
#                                           itemAction = "procSAGE()")
#                addVig2Menu("Set Target", "SAGE/SAGELyzer",
#                                           itemAction = "getTag()")
#                addVig2Menu("Select Libs", "SAGE/SAGELyzer",
#                                           itemAction = "selectLibs()")
#                addVig2Menu("Reset Defaults", "SAGE/SAGELyzer",
#                                           itemAction = "getDefaults()")
#                addVig2Menu("Run", "SAGE/SAGELyzer",
#                                           itemAction = "runSLyzer()")
#                addVig2Menu("Get Lib Counts", "SAGE/SAGELyzer",
#                                           itemAction = "getLibCounts()")
#                addVig2Menu("View Libs", "SAGE/SAGELyzer",
#                                           itemAction = "mapLib2File()")
#                addVig2Menu("Map SAGE", "SAGE/SAGEIntegrater",
#                                           itemAction = "mapSAGE2UG()")
#                addVig2Menu("Annotate Tags", "SAGE/SAGELyzer",
#                                           itemAction = "linkTag2UG()")
#                addVig2Menu("Reset", "SAGE/SAGELyzer",
#                                           itemAction = "setSLyzerArgs()")
#            }else if(.Platform$OS.type == "unix" && interactive()){
#               SAGE4Unix()
#            }
#        }
#    }
}

==> SAGElyzer_1.10.0.tar.gz: SAGElyzer/R/zzz.R <==

.onLoad <- function(libname, pkgname, where) {
    require("AnnBuilder", character.only = TRUE) || 
        stop("Package annotate unavailable")
    require("genefilter", character.only = TRUE) || 
        stop("Package genefilter unavailable")
    require("annotate", character.only = TRUE) || 
        stop("Package annotate unavailable")
    if(.Platform$OS.type == "windows"){
        require("RODBC", character.only = TRUE) || 
            stop("package RODBC unavailable")
    }else if(.Platform$OS.type == "unix"){
        require("Rdbi", character.only = TRUE) || 
            stop("Package Rdbi unavailable")
        require("RdbiPgSQL", character.only = TRUE) || 
            stop("Package RdbiPgSQL unavailable")
    }

    if(.Platform$OS.type == "windows" && require("Biobase") && interactive()
        && .Platform$GUI ==  "Rgui"){
        addVigs2WinMenu("SAGElyzer")
    }

    if(interactive()){
        setSLyzerArgs()
        if(require("tcltk", character.only = TRUE, quietly = TRUE)){
            require("tkWidgets", character.only = TRUE) || 
                stop("Package tkWidgets unavailable")
            SAGEWidget()
        }
    }


#    if(interactive()){
#        if(require(tcltk, quietly = TRUE)){
#            require(tkWidgets) || stop("Package tkWidgets unavailable")
#            if(.Platform$OS.type == "windows"){
#                require(Biobase) || stop("Package Biobase unavailable")
#                addVig2Menu("DBConnecter", "SAGE",
#                             itemAction = "getDBArgs()")
#                addVig2Menu("Get GEOSAGE", "SAGE/SAGEIntegrater",
#                                           itemAction = "SAGEFromGEO()")
#                addVig2Menu("Integrate SAGE", "SAGE/SAGEIntegrater",
#                                           itemAction = "procSAGE()")
#                addVig2Menu("Set Target", "SAGE/SAGELyzer",
#                                           itemAction = "getTag()")
#                addVig2Menu("Select Libs", "SAGE/SAGELyzer",
#                                           itemAction = "selectLibs()")
#                addVig2Menu("Reset Defaults", "SAGE/SAGELyzer",
#                                           itemAction = "getDefaults()")
#                addVig2Menu("Run", "SAGE/SAGELyzer",
#                                           itemAction = "runSLyzer()")
#                addVig2Menu("Get Lib Counts", "SAGE/SAGELyzer",
#                                           itemAction = "getLibCounts()")
#                addVig2Menu("View Libs", "SAGE/SAGELyzer",
#                                           itemAction = "mapLib2File()")
#                addVig2Menu("Map SAGE", "SAGE/SAGEIntegrater",
#                                           itemAction = "mapSAGE2UG()")
#                addVig2Menu("Annotate Tags", "SAGE/SAGELyzer",
#                                           itemAction = "linkTag2UG()")
#                addVig2Menu("Reset", "SAGE/SAGELyzer",
#                                           itemAction = "setSLyzerArgs()")
#            }else if(.Platform$OS.type == "unix" && interactive()){
#               SAGE4Unix()
#            }
#        }
#    }
}
